# 0-clean.r

# load and clean data that appears in the figures

library(reshape2)
library(plyr)
library(maps)
library(ggplot2)
# install.packages("ggsubplot")
library(ggsubplot)


###############################################################
###                    Map backgrounds                      ###
###############################################################
# getbox by Heike Hoffman, trims map polygons for figure backgrounds
# https://github.com/ggobi/paper-climate/blob/master/code/maps.r
getbox <- function (map, xlim, ylim) {
  # identify all regions involved
  small <- subset(map, (long > xlim[1]) & (long < xlim[2]) & (lat > ylim[1]) & (lat < ylim[2]))
  regions <- unique(small$region)
  small <- subset(map, region %in% regions)  
  
  # now shrink all nodes back to the bounding box
  small$long <- pmax(small$long, xlim[1])
  small$long <- pmin(small$long, xlim[2])
  small$lat <- pmax(small$lat, ylim[1])
  small$lat <- pmin(small$lat, ylim[2])
  
  # Remove slivvers
  small <- ddply(small, "group", function(df) {
    if (diff(range(df$long)) < 1e-6) return(NULL)
    if (diff(range(df$lat)) < 1e-6) return(NULL)
    df
  })
  
  small
}



## Central America for Figure 1-b
## adapted from map_nasa
# https://github.com/ggobi/paper-climate/blob/master/code/maps.r

# assembling data
world <- map_data("world")
states <- map_data("state")
states$group <- max(world$group) + states$group
both <- rbind(world, states)
americas <- getbox(both, xlim = c(-115, -55), ylim = c(-21.1, 36.6))

# building ggplot2 layer
map_americas <- list(
  geom_polygon(aes(long, lat, group = group), data = americas, fill = "grey70", 
    colour = "grey60", inherit.aes = FALSE, show_guide = FALSE),
  scale_x_continuous("", breaks = NULL, expand = c(0.02, 0)),
  scale_y_continuous("", breaks = NULL, expand = c(0.02, 0))) 


## Afghanistan for Figures 2 and 3
afghanistan <- getbox(world, c(60,75), c(28, 39))
map_afghan <- list(
  geom_polygon(aes(long, lat, group = group), data = afghanistan, 
    fill = "grey80", colour = "white", inherit.aes = FALSE, 
    show_guide = FALSE),
  scale_x_continuous("", breaks = NULL, expand = c(0.02, 0)),
  scale_y_continuous("", breaks = NULL, expand = c(0.02, 0)))

## Mexico and lower US for Figure 4
north_america <- getbox(both, xlim = c(-107.5, -80), ylim = c(11, 37.5))
map_north <- list(
  geom_polygon(aes(long, lat, group = group), data = north_america, fill = "grey80", 
    colour = "grey70", inherit.aes = FALSE, show_guide = FALSE),
  scale_x_continuous("", breaks = NULL, expand = c(0.02, 0)),
  scale_y_continuous("", breaks = NULL, expand = c(0.02, 0))) 

## Just the outlines of Mexico and lower US for Figure 4.c
lines_north <- list(
  geom_polygon(aes(long, lat, group = group), data = north_america, fill = NA, 
    colour = "black", inherit.aes = FALSE, show_guide = FALSE),
  scale_x_continuous("", breaks = NULL, expand = c(0.02, 0)),
  scale_y_continuous("", breaks = NULL, expand = c(0.02, 0))) 

## United States for Figure 8
us <- subset(getbox(both, xlim = c(-126, -65), ylim = c(24, 52)),
             region != "Great Lakes")

# making layer
map_us <- list(
  geom_polygon(aes(long, lat, group = group), data = us, fill = "grey80", 
    colour = "grey90", inherit.aes = FALSE, show_guide = FALSE),
  scale_x_continuous("", breaks = NULL, expand = c(0.02, 0)),
  scale_y_continuous("", breaks = NULL, expand = c(0.02, 0)))



###############################################################
###      Mauna Lau Carbon Dioxide Seasonal Trend Data       ###
###############################################################
# retrieve data
# must be connected to internet
carbon.a <- read.table(header = TRUE, nrow = 32,
  file = "http://www.stat.purdue.edu/~wsc/visualizing.datatables/carbon.dioxide")
carbon.b <- read.table(header = TRUE, skip = 33,
  file = "http://www.stat.purdue.edu/~wsc/visualizing.datatables/carbon.dioxide")
carbon <- cbind(carbon.a, carbon.b)
carbon <- t(carbon)
carbon <- melt(carbon)
carbon.ts <- ts(carbon$value, frequency = 12, start = c(1959, 1))

# decompose time series into long term trend, seasonal trend and remaining variation
decomp <- stl(carbon.ts, 25, 1)

# tidy data for ggplot2
carbon <- decomp$time.series
years <- floor(time(carbon))
months <- rep(1:12, 32)
carbon <- as.data.frame(carbon)
carbon$year <- as.numeric(years)
carbon$month <- months





###############################################################
###                 NASA Atmospheric data                   ###
###############################################################

# nasa data set loaded with ggsubplot package
# changing temperature units to fahrenheit
nasa$fahrenheit <- nasa$surftemp * 9 / 5 - 459.67
nasa$atmos.fahrenheit <- nasa$temperature * 9 / 5 - 459.67

# subset of data centered on Mexico for Figure 4
subnasa <- subset(nasa, long < -80 & lat > 10 & long > -107)





###############################################################
###                     diamonds data                       ###
###############################################################

# diamonds data set loaded with ggplot2 package
ordinary.diamonds <- subset(diamonds, price <= 5000 & price >= 700 &
  price < (7000 * carat - 1500)  & price > (6000 * carat - 2000))





###############################################################
###                wikileaks Afghan War Diary               ###
###############################################################

# casualties data set loaded with ggsubplot and used as is in figure 2
# regional casualty data included as a supplemental file to paper
# how about casualties over time in different parts of the country?
load("casualties-by-region.RData")





###############################################################
###              United States Temperature Data             ###
###############################################################

load("seasons.RData")
# trimming data
set.seed(1)
stns <- sample(seasons$stn, 500)
seasons <- seasons[seasons$stn %in% stns, ]
