# 1-figures.r
# make the figures in the paper

library(RColorBrewer)
library(ggplot2)
library(ggsubplot)

source("0-clean.r")


###############################################################
###                       Figure 1                          ###
###############################################################

# Figure 1.a. Mauna Lau CO2 seasonal components (also re-used as Figure 5.a)
ggplot(carbon) +
  geom_subplot(aes(month, mean(seasonal, na.rm = TRUE), group = month,
    subplot = geom_line(aes(year, seasonal - mean(seasonal)))), 
    ref = ref_hline(fill = "grey65")) + 
  scale_y_continuous(expression(paste("Seasonal component of trend in ", CO[2], 
    " (ppm)"))) +
  scale_x_continuous("month", breaks = c(1:12), 
    labels = c("J","F", "M", "A", "M", "J", "J", "A", "S", "O", "N", "D")) +
  ggtitle("Seasonal frequency components of Mauna Lau carbon \ndioxide time series between 1959 and 1990, by month")
ggsave("cycleplot.pdf", width = 7.776, height = 9.384)
ggsave("7a.pdf", width = 8, height = 8)


# Figure 1.b. temperature fluctuations
ggplot(nasa) + 
  map_americas + 
  geom_subplot(aes(long, lat, group = id, 
    subplot = geom_star(aes(r = fahrenheit, angle = date, 
      fill = mean(fahrenheit)), r.zero = FALSE))) + 
  scale_fill_gradient("Average\nTemp (F)   ", 
    breaks = c(55,60,65,70,75,80), guide = "legend") +
  ggtitle("Surface temperature fluctuations 1995 - 2001")
ggsave("glyphmap.pdf", width = 9, height = 9)



# Figure 1.c. binned diamonds data
ggplot(ordinary.diamonds) +
  geom_subplot2d(aes(carat, price, 
    subplot = geom_bar(aes(color, fill = color), position = "dodge", 
    color = "black", size = 1/10)), bins = c(10, 14), y_scale = free, 
    height.adjust = 0.8, width.adjust = 0.8, 
    ref = ref_box(aes(color = length(color)))) +
  scale_color_gradient("Total\ncount", low = "grey70", high = "black", guide = "legend") +
  scale_fill_brewer(palette = "Blues") +
  ggtitle("Diamonds, carat vs. price") + 
  coord_cartesian(ylim = c(400, 5400))
ggsave("binplot.pdf", width = 9, height = 9)



# Figure 1.d. raw diamonds data
ggplot(ordinary.diamonds) +
  geom_point(aes(carat, price, color = color)) + 
  scale_color_brewer(palette = "Blues") +
  ggtitle("Diamonds, carat vs. price") + 
  coord_cartesian(ylim = c(400, 5400))
ggsave("overplot.pdf", width = 9, height = 9)





###############################################################
###                       Figure 2                          ###
###############################################################

# Figure 2.a. raw Afghanistan casualty data
ggplot(casualties) + 
  map_afghan +
  geom_point(aes(lon, lat, color = victim), size = 1.75) +
  ggtitle("location of casualties by type") + 
  coord_map() +
  scale_colour_manual(values = rev(brewer.pal(5,"Blues"))[1:4])
ggsave("afgpoints.pdf", width = 7, height = 7)



# Figure 2.b. Afghanistan casualty heat map
ggplot(casualties) + 
  map_afghan +
  geom_bin2d(aes(lon, lat), bins = 15) +
  ggtitle("number of casualties by location") +
  scale_fill_continuous(guide = guide_legend()) +
  coord_map()
ggsave("afgtile.pdf", width = 7, height = 7)



# Figure 2.c. Afghanistan casualty embedded bar graphs (marginal distributions)
ggplot(casualties) + 
  map_afghan +
  geom_subplot2d(aes(lon, lat, 
    subplot = geom_bar(aes(victim, ..count.., fill = victim), 
      color = rev(brewer.pal(5,"Blues"))[1], size = 1/4)), bins = c(15,12), 
      ref = NULL, width = rel(0.8), height = rel(1)) + 
  ggtitle("casualty type by location\n(Marginal distribution)") + 
  coord_map() +
  scale_fill_manual(values = rev(brewer.pal(5,"Blues"))[c(1,4,2,3)]) 
ggsave("casualties.pdf", width = 7, height = 7)



# Figure 2.d. Afghanistan casualty embedded bar graphs (conditional distributions)
ggplot(casualties) + 
  map_afghan +
  geom_subplot2d(aes(lon, lat,
    subplot = geom_bar(aes(victim, ..count.., fill = victim), 
      color = rev(brewer.pal(5,"Blues"))[1], size = 1/4)), bins = c(15,12), 
      ref = ref_box(fill = NA, color = rev(brewer.pal(5,"Blues"))[1]), width = rel(0.7), height = rel(0.6), y_scale = free) + 
  ggtitle("casualty type by location\n(Conditional distribution)") +
  coord_map() +
  scale_fill_manual(values = rev(brewer.pal(5,"Blues"))[c(1,4,2,3)]) 
ggsave("casualties2.pdf", width = 7, height = 7)





###############################################################
###                       Figure 3                          ###
###############################################################

# Figure 3.a. Temperature data as embedded scatterplots 
ggplot(subnasa) + 
  map_north + 
  geom_subplot(aes(long[1], lat[1], group = id, 
    subplot = geom_point(aes(x = surftemp, y = temperature), size = 1/2)), 
      width = 3, height = 3) +
  ggtitle("Surface temp vs. atmospheric temp") + 
  coord_map()
ggsave("no-sum.pdf", width = 6, height = 6)


# Figure 3.b. Temperature data as embedded line graphs
# notice free x and y scales
ggplot(subnasa) + 
  map_north + 
  geom_subplot(aes(long[1], lat[1], group = id, 
    subplot = geom_smooth(aes(x = surftemp, y = temperature), se = F)), 
    x_scale = free, y_scale = free) +
  ggtitle("Surface temp vs. atmospheric temp") + 
  coord_map()
ggsave("some-sum.pdf", width = 6, height = 6)


# Figure 3.c. Temperature data as heat map
ggplot(subnasa) + 
  lines_north + 
  geom_subplot(aes(long[1], lat[1], group = id, 
    subplot = geom_blank(aes(long, lat))), 
    width = rel(1), height = rel(1), 
    ref = ref_box(aes(fill = mean(fahrenheit)), alpha = 0.8, color = NA)) +
  ggtitle("Average temperature (F)") + 
  scale_fill_continuous("Average\nTemp (F)", guide = "legend", breaks = c(55, 60, 65, 70, 75, 80)) +
  coord_map()
ggsave("all-sum.pdf", width = 8, height = 6)


###############################################################
###                       Figure 4                          ###
###############################################################
example_data <- structure(list(
  month = factor(1:12, labels = c("Jan", "Feb", "March", "April", 
      "May", "June", "July", "Aug", "Sept", "Oct", "Nov", "Dec")), 
  co2 = c(-0.06, 0.6, 1.31, 2.42, 2.92, 2.3, 0.84, -1.19, -2.97, 
           -3.21, -2.03, -0.95), 
  season = c("Winter", "Winter", "Spring", "Spring", "Spring", 
             "Summer", "Summer", "Summer", "Fall", "Fall", "Fall", 
             "Winter")), 
  .Names = c("month", "co2", "season"), 
  row.names = c(NA, -12L), class = "data.frame")

ggplot(example_data) + 
  geom_point(mapping = aes(x = month, y = co2), size = 5) +
  scale_x_discrete(labels = c("J", "F", "M", "A", "M", "J", "J",
                              "A", "S", "O", "N", "D"))
ggsave("fig4a.pdf", width = 6, height = 6)


###############################################################
###                       Figure 5                          ###
###############################################################

ggplot(example_data) + 
  geom_point(mapping = aes(x = month, y = co2, shape = season), size = 5) +
  scale_x_discrete(labels = c("J", "F", "M", "A", "M", "J", "J",
                              "A", "S", "O", "N", "D"))
ggsave("fig5a.pdf", width = 6, height = 6)





###############################################################
###                       Figure 6                          ###
###############################################################
other_data <- structure(list(
  month = factor(1:12, labels = c("Jan", "Feb", "March", "April", 
      "May", "June", "July", "Aug", "Sept", "Oct", "Nov", "Dec")), 
  co2 = c(2.1, 1.83, 1.3, 1.11, 0.74, 0.28, -0.08, - 0.84, -1.33, -2.56, 
           -3.00, -3.05), 
  season = c("Winter", "Winter", "Spring", "Spring", "Spring", 
             "Summer", "Summer", "Summer", "Fall", "Fall", "Fall", 
             "Winter")), 
  .Names = c("month", "co2", "season"), 
  row.names = c(NA, -12L), class = "data.frame")

ggplot(other_data) + 
  geom_point(mapping = aes(x = month, y = co2, shape = season), size = 5) +
  scale_x_discrete(labels = c("J", "F", "M", "A", "M", "J", "J",
                              "A", "S", "O", "N", "D"))
ggsave("fig6a.pdf", width = 6, height = 6)


###############################################################
###                       Figure 7                          ###
###############################################################

# Figure 7.a. is identical to Figure 1.a


# Figure 7.b. subplot for March seasonal components trend
ggplot(carbon[carbon$month == 3, ]) +
  geom_subplot(aes(month, mean(seasonal, na.rm = TRUE), group = month,
    subplot = geom_line(aes(year, seasonal - mean(seasonal)), size = 2)), 
    ref = ref_hline(fill = "grey65", thickness = 0.4)) + 
  scale_y_continuous("Seasonal component") +
  scale_x_continuous("month", breaks = 3, labels = "M") +
  ggtitle("March Measurements\n(1959 - 1990)") +
  coord_cartesian(ylim = c(0.5,2))
ggsave("7b.pdf", width = 4, height = 4)


# Figure 7.c. Carbon Dioxide seasonal components embedded plot as scatterplot
ggplot(carbon) +
  geom_subplot(aes(month, mean(seasonal, na.rm = TRUE), group = month,
    subplot = geom_blank(aes(x = month, y = seasonal))), 
      ref = ref_box(fill = "grey10", color = NA)) + 
  scale_y_continuous("Seasonal component") +
  scale_x_continuous(breaks = c(1:12), 
    labels = c("J","F", "M", "A", "M", "J", "J", "A", "S", "O", "N", "D")) +
  ggtitle("Average seasonsal\ncomponent by month")
ggsave("7c.pdf", width = 4, height = 4)




###############################################################
###                       Figure 8                          ###
###############################################################

# Figure 8.a bar geom
ggplot(mtcars) + geom_rect(aes(xmin = -0.25, xmax = 0.25, ymin = 0, ymax = 21)) + 
  scale_x_continuous("") + 
  scale_y_continuous("") +
  ggtitle("bar") +
  coord_cartesian(xlim = c(-0.8, 0.8), ylim = c(0, 25))
ggsave("fig8a.pdf", width = 3.5, height = 4)



# Figure 8.b boxplot geom
ggplot(mtcars) + geom_boxplot(aes(0, mpg - 10)) +
  scale_x_continuous("") +
  scale_y_continuous("") + 
  ggtitle("boxplot") +
  coord_cartesian(xlim = c(-0.8, 0.8), ylim = c(0, 25))
ggsave("fig8b.pdf", width = 3.5, height = 4)


# Figure 8.c point geom
ggplot(mtcars) + geom_point(aes(0, 12.5), size = 15) +
  scale_x_continuous("") +
  scale_y_continuous("") + 
  ggtitle("point") +
  coord_cartesian(xlim = c(-0.8, 0.8), ylim = c(0, 25))
ggsave("fig8c.pdf", width = 3.5, height = 4)


###############################################################
###                       Figure 8                          ###
###############################################################

# Figure 9.a scatterplot
ggplot(nasa) +
 geom_point(aes(x = surftemp, y = temperature)) +
 ggtitle("Surface temperature vs. atmospheric temperature (all observations)")
ggsave("fig9a.pdf", width = 7, height = 7)



# Figure 9.b scatterplot subplots
ggplot(nasa) +
   map_americas +
   geom_subplot(aes(x = long, 
                    y = lat, 
                    group = id,
                    subplot = geom_point(aes(x = surftemp, 
                                             y = temperature), 
                                         size = .5, width = 3, height = 3))) +
  ggtitle("Surface temperature vs. atmospheric temperature (by location)")
ggsave("fig9b.pdf", width = 7, height = 7)

# Figure 9.c star subplots, same as 
# Figure 1.b. temperature fluctuations
ggplot(nasa) + 
  map_americas + 
  geom_subplot(aes(long, lat, group = id, 
    subplot = geom_star(aes(r = fahrenheit, angle = date, 
      fill = mean(fahrenheit)), r.zero = FALSE))) + 
  scale_fill_gradient("Average\nTemp (F)   ", 
    breaks = c(55,60,65,70,75,80), guide = "legend") +
  ggtitle("Surface temperature fluctuations 1995 - 2001")
ggsave("9c.pdf", width = 7, height = 7)

# Figure 9.d star subplots, new axes

ggplot(nasa) + 
  geom_subplot(aes(max(surftemp), min(surftemp), group = id, 
    subplot = geom_star(aes(r = fahrenheit, angle = date, 
      fill = mean(fahrenheit)), r.zero = FALSE)), width = 1.4, height = 1.5) + 
  scale_fill_gradient("Average\nTemp (F)   ", 
    breaks = c(55,60,65,70,75,80), guide = "legend") +
  ggtitle("Temperature fluctuations arranged by minimum and maximums.") +
  ylab("Minimum temperature") +
  xlab("Maximum temperature")
ggsave("fig9d.pdf", width = 7, height = 7)


###############################################################
###               Figure A1 (Appendix)                      ###
###############################################################

# Figure A1.a, a star geom
one_nasa <- nasa[nasa$id == "1-1", ]
ggplot(one_nasa) +
  geom_line(aes(x = date, y = fahrenheit)) +
  coord_polar() +
  ggtitle("line geom with polar coordinates")
ggsave("star.pdf", width = 4, height = 4)

# Figure A1.b, a star geom
ggplot(one_nasa) +
  geom_freqpoly(aes(x = ozone)) + 
  coord_polar() +
  ggtitle("freqpoly geom with polar coordinates")
ggsave("freqstar.pdf", width = 4, height = 4)


# Figure A1.c, a coxcomb geom
ggplot(diamonds) +
  geom_bar(aes(x = color, fill = color)) +
  coord_polar() +
  ggtitle("bar geom with polar coordinates")
ggsave("coxcomb.pdf", width = 4.75, height = 4)

# Figure A1.d, star geom
ggplot(one_nasa) +
  geom_star(aes(angle = date, r = fahrenheit, 
    fill = mean(fahrenheit)), r.zero = FALSE) + 
  ggtitle("star geom") +
  guides(fill = "none")
ggsave("A2a.pdf", width = 4, height = 4)

# Figure A1.e, freqstar geom
ggplot(one_nasa) +
  geom_freqstar(aes(angle = ozone, fill = mean(ozone))) + 
  ggtitle("freqstar geom") +
  guides(fill = "none")
ggsave("A1e.pdf", width = 4, height = 4)

# Figure A1.f, coxcomb geom
ggplot(diamonds) +
  geom_coxcomb(aes(angle = color, fill = color)) +
  ggtitle("coxcomb geom")
ggsave("A1f.pdf", width = 4.75, height = 4)

###############################################################
###               Figure A3 (Appendix)                      ###
###############################################################

# Figure A3.a overplotted ozone vs. temperature
ggplot(nasa) + 
  geom_point(aes(x = atmos.fahrenheit, y = ozone, color = lat)) +
  scale_color_continuous("latitude") +
  scale_x_continuous("temperature (F)") +
  ggtitle("\nozone vs. temperature")


# Figure A3.b. Combine like points, plot their means
ggplot(nasa) + 
  ply_aes(geom_point(aes(x = mean(atmos.fahrenheit), y = mean(ozone), 
    color = lat[1], group = interaction(long, lat)))) +
  scale_x_continuous("Mean temperature (F)") +
  scale_y_continuous("Mean ozone") + 
  scale_color_continuous("latitude") +
  ggtitle("Mean ozone vs. mean temperature\none point per measurement location")

###############################################################
###                       Figure A4                         ###
###############################################################

# A4.a, Default width and height, same as 1.b
ggplot(nasa) + 
  map_americas + 
  geom_subplot(aes(long, lat, group = id, 
    subplot = geom_star(aes(r = fahrenheit, angle = date, 
      fill = mean(fahrenheit)), r.zero = FALSE))) + 
  scale_fill_gradient("Average\nTemp (F)   ", 
    breaks = c(55,60,65,70,75,80), guide = "legend") +
  ggtitle("Glyphs with default width and heights")
ggsave("figA4a.pdf", width = 6, height = 6)

# Decreased width and height
ggplot(nasa) + 
  map_americas + 
  geom_subplot(aes(long, lat, group = id, 
    subplot = geom_star(aes(r = fahrenheit, angle = date, 
      fill = mean(fahrenheit)), r.zero = FALSE)),
    width = 1.5, height = 1.5) + 
  scale_fill_gradient("Average\nTemp (F)   ", 
    breaks = c(55,60,65,70,75,80), guide = "legend") +
  ggtitle("Decreased width and height"s)
ggsave("figA4b.pdf", width = 6, height = 6)

# A4.c, increased width and height
ggplot(nasa) + 
  map_americas + 
  geom_subplot(aes(long, lat, group = id, 
    subplot = geom_star(aes(r = fahrenheit, angle = date, 
      fill = mean(fahrenheit)), r.zero = FALSE)),
    width = rel(1.5), height = rel(1.5)) + 
  scale_fill_gradient("Average\nTemp (F)   ", 
    breaks = c(55,60,65,70,75,80), guide = "legend") +
  ggtitle("Increased width and heights, set with rel()")
ggsave("figA4c.pdf", width = 6, height = 6)


###############################################################
###                       Figure A5                         ###
###############################################################

# Figure A5.a. Annual temperatures at 416 weather stations
ggplot(seasons) + 
  map_us + 
  geom_subplot(aes(lon[1], lat[1], group = stn, 
    subplot = geom_line(aes(x = time, y = pred)), color = "white"), height = 1, 
      width = 2, ref = ref_box(aes(fill = avg))) + 
  ggtitle('Annual temperature pattern for 416 weather stations\nposition = "identity"')
  scale_fill_continuous("Mean\ntemperature (F)") +
  coord_map()


# Fibure A5.b. Annual temperatures, overlapping subplots merged
ggplot(seasons) + 
  map_us + 
  geom_subplot(aes(lon[1], lat[1], group = stn, 
    subplot = geom_line(aes(x = time, y = pred)), color = "white"), height = 1, 
      width = 2, ref = ref_box(aes(fill = avg)), position = "merge") + 
  ggtitle('position = "merge"') +
  scale_fill_continuous("Mean\ntemperature (F)") +
  coord_map()


# Figure A5.c. Typical temperature trend by bin
ggplot(seasons) + 
  map_us + 
  geom_subplot2d(aes(lon, lat, 
    subplot = geom_line(aes(x = time, y = pred), color = "white")), 
      binwidth = c(2, 1), ref = ref_box(aes(fill = avg))) + 
  ggtitle('geom_subplot2d') +
  scale_fill_continuous("Mean\ntemperature (F)") +
  coord_map()






###############################################################
###                       Figure A6                         ###
###############################################################

# Figure A6.a. box used as reference
ggplot(carbon[carbon$month == 3, ]) +
  geom_subplot(aes(month, mean(seasonal, na.rm = TRUE), group = month,
    subplot = geom_line(aes(date, seasonal - mean(seasonal)), size = 2)), 
      ref = ref_box(size = 2)) + 
  scale_y_continuous("trend component") +
  scale_x_continuous(breaks = 3, labels = "M") +
  ggtitle("ref = ref_box()") +
  coord_cartesian(ylim = c(0.5,2))



# Figure A6.b. horizontal line used as reference
ggplot(carbon[carbon$month == 3, ]) +
  geom_subplot(aes(month, mean(seasonal, na.rm = TRUE), group = month,
    subplot = geom_line(aes(year, seasonal - mean(seasonal)), size = 2)), 
    ref = ref_hline(fill = "grey65", thickness = 0.4)) + 
  scale_y_continuous("trend component") +
  scale_x_continuous(breaks = 3, labels = "M") +
  ggtitle("ref = ref_hline()") +
  coord_cartesian(ylim = c(0.5,2))



# Figure A6.c. vertical line used as reference
ggplot(carbon[carbon$month == 3, ]) +
  geom_subplot(aes(month, mean(seasonal, na.rm = TRUE), group = month,
    subplot = geom_line(aes(year, seasonal - mean(seasonal)), size = 2)), 
      ref = ref_vline(fill = "grey65")) + 
  scale_y_continuous("trend component") +
  scale_x_continuous(breaks = 3, labels = "M") +
  ggtitle("ref = ref_vline()") +
  coord_cartesian(ylim = c(0.5,2))

